@@ -25,6 +25,13 @@ class Service(Enum):
 	WEAPON_DETECTION = 4,
 	LIE_DETECTION = 5,
 	NIGHT_DAY = 6,
+	CAB_VIOLENCE = 7,
+	TEMPORAL = 8,
+	FACE_RECOG = 9,
+	GENERAL_VIOLENCE=10,
+	PEDESTRIAN_DETECTION=11,
+	CROWD_COUNTING=12,
+	DRESS_INSIGHTS = 13,
 
 	def get_uri(self):
 		return service_uri_map.get(self, None)
@@ -37,6 +44,13 @@ service_uri_map = {
 	Service.WEAPON_DETECTION: "weapon-detection/",
 	Service.LIE_DETECTION: "lie-detection/",
 	Service.NIGHT_DAY: "night-day/",
+	Service.CAB_VIOLENCE: "cab-violence/",
+	Service.TEMPORAL:"process-temporal/",
+	Service.FACE_RECOG: "face-recog-bulk/",
+	Service.GENERAL_VIOLENCE:"violence-detection/",
+	Service.PEDESTRIAN_DETECTION:"pedestrian-detection/",
+	Service.CROWD_COUNTING:"crowd-counting/",
+	Service.DRESS_INSIGHTS: "dress-insights/",
 
 }
 
@@ -47,19 +61,22 @@ class RealTimeClient:
 
 	def get_or_create_eventloop(self):
 		try:
+			print("getting loop")
 			return asyncio.get_event_loop()
 		except RuntimeError as ex:
 			if "There is no current event loop in thread" in str(ex):
 				loop = asyncio.new_event_loop()
+				print("no loop !!!")
 				asyncio.set_event_loop(loop)
 				return asyncio.get_event_loop()
 
-	def __init__(self, service, on_receive, batch_size, on_network_status_change, token=None):
+	def __init__(self, service, on_receive, batch_size, on_network_status_change, token=None, databaseID=None):
 		self.service = service
 		self.on_network_status_change = on_network_status_change
 		self.url = self.protocol + HOST + "/" + self.route + service.get_uri()
 		self.path = os.path.join(os.getcwd(), "media", "directory_streams", "test_stream")
 		print(self.url)
+		self.databaseID = databaseID
 		print("got token")
 		print(token)
 		self.token = token
@@ -75,6 +92,7 @@ class RealTimeClient:
 		loop = self.get_or_create_eventloop()
 		loop.run_until_complete(self._connect())
 		loop.run_until_complete(self.set_batch_size(batch_size))
+		loop.run_until_complete(self.set_databaseID(databaseID))
 
 	async def start_stream(self, byte_array):
 		while self.websocket is None:
@@ -118,6 +136,30 @@ class RealTimeClient:
 			self.websocket = None
 			await self.on_network_status_change()
 
+	async def set_databaseID(self, databaseID):
+		print("setting batch size")
+		while self.websocket is None:
+			# if connection is closed we wait for reconnection
+			print("none")
+			await asyncio.sleep(1)
+			continue
+		try:
+			if is_connected():
+				await self.websocket.send(json.dumps({
+					"action": 'set_database',
+					"database_id": databaseID
+				}))
+			else:
+				self.websocket = None
+				await self.on_network_status_change()
+
+		except websockets.exceptions.ConnectionClosed:
+			print("connection closed in setting batch size")
+			print("re-establishing connection...")
+			self.websocket = None
+			await self.on_network_status_change()
+
+
 	async def start_frame(self, byte_length, syncid):
 		print("starting frame")
 		self.syncid = self.syncid + 1
